@@ -88,7 +88,7 @@ class PomodoroBlurredLightbox extends Lightbox.Lightbox {
             radialEffect: false,
         });
 
-        if (Clutter.feature_available(Clutter.FeatureFlags.SHADERS_GLSL)) {
+        if (Utils.versionCheck('42.0') || Clutter.feature_available(Clutter.FeatureFlags.SHADERS_GLSL)) {  // TODO there is no such feature flag since 42
             // Clone the group that contains all of UI on the screen. This is the
             // chrome, the windows, etc.
             this._uiGroup = new Clutter.Clone({ source: Main.uiGroup, clip_to_allocation: true });
@@ -293,6 +293,7 @@ var ModalDialog = GObject.registerClass({
 
     _onIdleMonitorBecameIdle(monitor) {
         let pushModalTries = 0;
+        let pushModalInterval = Math.floor(1000 / PUSH_MODAL_RATE);
         let timestamp = global.get_current_time();
 
         if (this._pushModalWatchId) {
@@ -306,7 +307,7 @@ var ModalDialog = GObject.registerClass({
 
         this._pushModalSource = GLib.timeout_add(
             GLib.PRIORITY_DEFAULT,
-            Math.floor(1000 / PUSH_MODAL_RATE),
+            pushModalInterval,
             () => {
                 pushModalTries += 1;
 
@@ -315,7 +316,8 @@ var ModalDialog = GObject.registerClass({
                     return GLib.SOURCE_REMOVE;  // success
                 }
 
-                if (pushModalTries > PUSH_MODAL_TIME_LIMIT * PUSH_MODAL_RATE) {
+                if (pushModalTries * pushModalInterval >= PUSH_MODAL_TIME_LIMIT) {
+                    Utils.logWarning('Unable to push modal. Closing the modal dialog...');
                     this.close(true);
                     this._pushModalSource = 0;
                     return GLib.SOURCE_REMOVE;  // failure
@@ -474,6 +476,10 @@ var ModalDialog = GObject.registerClass({
                 Main.popModal(grab);
                 return false;
             }
+        } else {
+            if (!grab) {
+                return false;
+            }
         }
 
         this._grab = grab;
